package de.hazewood.rylius.mlgj1.elements.props;

import de.hazewood.rylius.mlgj1.Element;
import de.hazewood.rylius.mlgj1.levels.Level;
import org.newdawn.slick.GameContainer;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.geom.Vector2f;

import java.util.LinkedList;
import java.util.List;
import java.util.Random;

public class Tree extends Element {

    private final static Random RANDOM = new Random();
    private final LinkedList<Element> children;
    private Leaves leaves;

    public Tree(int apples) {
        this(apples, 400);
    }

    public Tree(int apples, int ground) {
        super(null);
        children = new LinkedList<Element>();

        children.add(new Trunk());
        leaves = new Leaves();
        children.add(leaves);

        for (int i = 0; i < apples; i++) {
            Apple a = new Apple();
            a.setOffset(new Vector2f(128 + (RANDOM.nextInt(256) - 128), 96 + (RANDOM.nextInt(160) - 80)));
            a.setGround(ground);
            children.add(a);
        }
    }

    public void buck() {
        for (Element el : children) {
            if (el instanceof Apple) {
                Apple apple = (Apple) el;
                if (!apple.onGround()) {
                    apple.activate();
                }
            }
        }
    }

    @Override
    public void init(Level level) {
        super.init(level);

        for (Element el : children) {
            el.init(level);
            el.getPos().set(pos.getX(), pos.getY());
        }
    }

    @Override
    public void update(GameContainer gc, int delta) {
        super.update(gc, delta);

        List<Element> remove = new LinkedList<Element>();
        for (Element el : children) {
            el.update(gc, delta);
            if (el.isRemoveable()) {
                remove.add(el);
            }
        }
        children.removeAll(remove);

        if (leaves != null && leaves.clicked(gc.getInput())) {
        } else if (children.get(0).clicked(gc.getInput())) {
            buck();
        }
    }

    @Override
    public void draw(GameContainer gc, Graphics g) {
        super.draw(gc, g);

        for (Element el : children) {
            el.draw(gc, g);
        }
    }

    @Override
    public boolean combine(Element other) {
        return false;
    }

    public Element detachLeaves() {
        leaves = null;
        return children.remove(1);
    }

    public Element getLeaves() {
        return leaves;
    }

    public LinkedList<Element> getChildren() {
        return children;
    }
}
