package de.hazewood.rylius.mlgj1.levels;

import de.hazewood.rylius.mlgj1.Game;
import de.hazewood.rylius.mlgj1.MLGJ1;
import de.hazewood.rylius.mlgj1.elements.chars.Applejack;
import de.hazewood.rylius.mlgj1.elements.chars.Discord;
import de.hazewood.rylius.mlgj1.elements.props.Apple;
import de.hazewood.rylius.mlgj1.elements.props.CottonCandyCloud;
import de.hazewood.rylius.mlgj1.elements.props.Tree;
import org.newdawn.slick.GameContainer;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.Image;
import org.newdawn.slick.geom.Vector2f;

public class MazeApplejack extends Level {

    private Tree tree;
    private Applejack aj;
    private Image water;

    public MazeApplejack(MLGJ1 main) {
        super(main, Game.image("backdrops/aj_1"), 20000);
        water = Game.image("backdrops/aj_1_water");

        discord = new Discord();
        discord.getPos().set(32, 16);
        add(discord);

        CottonCandyCloud cloud = new CottonCandyCloud();
        cloud.getPos().set(276, 16);
        cloud.setGround(330);
        add(cloud);

        tree = new Tree(10);
        tree.getPos().set(480, 64);
        add(tree);

        aj = new Applejack();
        aj.getPos().set(440, 300);
        add(aj);
    }

    @Override
    protected void onEvent(Event ev) {
        pickupSound.play();

        if (selected != null && ev.getSource() != selected) {
            if (ev.getName().equals("applejack") && selected == tree.getLeaves()) {
                tree.getLeaves().getPickupSound().play();
                aj.attach(tree.detachLeaves(), new Vector2f(-50, -20));
                aj.getVel().set(-6, 0);
                aj.setGravity(new Vector2f(0, 0.0625f));
                finished = true;
            } else if (selected.combine(ev.getSource())) {
                return;
            }
        }

        if (ev.getName().equals("apple")) {
            ((Apple) ev.getSource()).activate();
        } else if (ev.getSource().isPickable()) {
            if (ev.getName().equals("leaves")) {
                tree.buck();
            }
            pick(ev.getSource());
        }
    }

    @Override
    protected void updateInternal(GameContainer gc, int delta) {
        if (!finished && remainingTime() <= 0) {
            aj.leave();
            finished = true;
            main.getState().put("maze_aj", 0);
        } else if (aj.left()) {
            main.loadLevel(new Maze(main));
        } else if (aj.getPos().getY() > 1300) {
            main.getState().put("maze_aj", 1);
            main.loadLevel(new Maze(main));
        }
    }

    @Override
    protected void drawInternal(GameContainer gc, Graphics g) {
        drawRemainingTime(g);

        if (finished && aj.getVel().getX() > 0) {
            loss.draw();
        }

        if (aj.getPos().getY() > 600) {
            win.draw();
        }

        water.draw();
    }
}
