package de.hazewood.rylius.mlgj1.levels;

import de.hazewood.rylius.mlgj1.Game;
import de.hazewood.rylius.mlgj1.MLGJ1;
import de.hazewood.rylius.mlgj1.elements.chars.Discord;
import de.hazewood.rylius.mlgj1.elements.chars.RainbowDash;
import de.hazewood.rylius.mlgj1.elements.props.Apple;
import de.hazewood.rylius.mlgj1.elements.props.Tree;
import org.newdawn.slick.GameContainer;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.Sound;
import org.newdawn.slick.geom.Vector2f;

public class MazeRainbowDash extends Level {

    private RainbowDash rd;
    private Tree tree1;
    private Tree tree2;
    private int timeout;
    private Sound explosion;

    public MazeRainbowDash(MLGJ1 main) {
        super(main, Game.image("backdrops/rarity_1"), 20000);
        timeout = 2000;
        explosion = Game.sound("explosion");

        tree2 = new Tree(0, 450);
        tree2.getPos().set(480, 128);
        add(tree2);

        tree1 = new Tree(20, 450);
        tree1.getPos().set(64, 128);
        add(tree1);

        discord = new Discord();
        discord.getPos().set(32, 128);
        add(discord);

        rd = new RainbowDash(tree1.getChildren());
        rd.getPos().set(760, 320);
        rd.getVel().set(-2, 0);
        add(rd);
    }

    @Override
    protected void onEvent(Event ev) {
        if (finished) {
            return;
        }

        pickupSound.play();

        if (selected != null && ev.getSource() != selected) {
            if (selected.combine(ev.getSource())) {
                return;
            }
        }

        if (ev.getName().equals("apple")) {
            Apple apple = (Apple) ev.getSource();
            apple.getVel().set(9, 0);
            apple.setGravity(new Vector2f(0, -0.1f));
        } else if (ev.getSource().isPickable()) {
            if (ev.getName().equals("leaves")) {
                if (ev.getSource() == tree1.getLeaves()) {
                    tree1.buck();
                } else if (ev.getSource() == tree2.getLeaves()) {
                    tree2.buck();
                }
            }
            pick(ev.getSource());
        }
    }

    @Override
    protected void updateInternal(GameContainer gc, int delta) {
        if (finished) {
            timeout -= delta;
            if (timeout <= 0) {
                main.loadLevel(new Maze(main));
            }
        } else {
            if (rd.getPos().getX() <= 224) {
                main.getState().put("maze_rd", 0);
                explosion.play();
                timeout /= 2;
                finished = true;
                rd.getVel().set(0, 0);
            } else if (rd.getPos().getX() > 900) {
                main.getState().put("maze_rd", 1);
                finished = true;
            }
        }
    }

    @Override
    protected void drawInternal(GameContainer gc, Graphics g) {
        if (rd.getPos().getX() <= 224) {
            loss.draw();
        } else if (rd.getPos().getX() > 900) {
            win.draw();
        }
    }
}
